@@ -1,18 +1,26 @@
 package ACME::CPANPLUS::Module::With::Core::PreReq;
+$ACME::CPANPLUS::Module::With::Core::PreReq::VERSION = '0.06';
+#ABSTRACT: Fake module with a prereq that is a core module for testing CPANPLUS
 
 use strict;
 use warnings;
 
-our $VERSION = '0.04';
-
 qq[Nobody here but us chickens];
 
 __END__
 
+=pod
+
+=encoding UTF-8
+
 =head1 NAME
 
 ACME::CPANPLUS::Module::With::Core::PreReq - Fake module with a prereq that is a core module for testing CPANPLUS
 
+=head1 VERSION
+
+version 0.06
+
 =head1 SYNOPSIS
 
  # erm
@@ -28,12 +36,13 @@ No moving parts and nothing to see.
 
 =head1 AUTHOR
 
-Chris C<BinGOs> Williams <chris@bingosnet.co.uk>
+Chris Williams <chris@bingosnet.co.uk>
 
-=head1 LICENSE
+=head1 COPYRIGHT AND LICENSE
 
-Copyright E<copy> Chris Williams
+This software is copyright (c) 2017 by Chris Williams.
 
-This module may be used, modified, and distributed under the same terms as Perl itself. Please see the license that came with your Perl distribution for details.
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
 
 =cut
